platform_of_key

Function platform_of_key 

pub fn platform_of_key(key: &str) -> &'static str
The platform label for an existing store key, derived from its suffix: "linux-x86_64" / "linux-aarch64" for suffixed keys, "windows" for anything else (bare keys are Windows by definition of the key scheme). Used by the releases listing, which only has keys to look at.