pub struct JobRun {
pub run_id: String,
pub status: RunStatus,
pub started_at: DateTime<Utc>,
pub finished_at: Option<DateTime<Utc>>,
pub exit_code: Option<i32>,
}Expand description
Compact summary of a past run — what the Client App shows next to the job’s “Run again” button.
Fields
run_id: Stringstatus: RunStatusstarted_at: DateTime<Utc>finished_at: Option<DateTime<Utc>>exit_code: Option<i32>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for JobRun
impl<'de> Deserialize<'de> for JobRun
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for JobRun
impl JsonSchema for JobRun
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for JobRun
impl RefUnwindSafe for JobRun
impl Send for JobRun
impl Sync for JobRun
impl Unpin for JobRun
impl UnsafeUnpin for JobRun
impl UnwindSafe for JobRun