pub struct MaintenanceDeferParams {
pub schedule_id: String,
pub duration: DeferDuration,
}Expand description
maintenance.defer params — push back a scheduled reboot. The
agent records the deferral and skips the next fire of the named
schedule for the chosen window (SPEC 2.1: 15m / 30m / 1h).
Fields
schedule_id: Stringduration: DeferDurationTrait Implementations
Sourceimpl Clone for MaintenanceDeferParams
impl Clone for MaintenanceDeferParams
Sourcefn clone(&self) -> MaintenanceDeferParams
fn clone(&self) -> MaintenanceDeferParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MaintenanceDeferParams
impl Debug for MaintenanceDeferParams
Sourceimpl<'de> Deserialize<'de> for MaintenanceDeferParams
impl<'de> Deserialize<'de> for MaintenanceDeferParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MaintenanceDeferParams
impl JsonSchema for MaintenanceDeferParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MaintenanceDeferParams
impl RefUnwindSafe for MaintenanceDeferParams
impl Send for MaintenanceDeferParams
impl Sync for MaintenanceDeferParams
impl Unpin for MaintenanceDeferParams
impl UnsafeUnpin for MaintenanceDeferParams
impl UnwindSafe for MaintenanceDeferParams