pub struct MaintenanceListResult {
pub items: Vec<MaintenanceItem>,
}Fields
items: Vec<MaintenanceItem>Trait Implementations
Sourceimpl Clone for MaintenanceListResult
impl Clone for MaintenanceListResult
Sourcefn clone(&self) -> MaintenanceListResult
fn clone(&self) -> MaintenanceListResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MaintenanceListResult
impl Debug for MaintenanceListResult
Sourceimpl<'de> Deserialize<'de> for MaintenanceListResult
impl<'de> Deserialize<'de> for MaintenanceListResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MaintenanceListResult
impl JsonSchema for MaintenanceListResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MaintenanceListResult
impl RefUnwindSafe for MaintenanceListResult
impl Send for MaintenanceListResult
impl Sync for MaintenanceListResult
impl Unpin for MaintenanceListResult
impl UnsafeUnpin for MaintenanceListResult
impl UnwindSafe for MaintenanceListResult