pub struct NotificationAckEntry {
pub pc_id: String,
pub user_sid: String,
pub acked_at: DateTime<Utc>,
}Expand description
One recipient’s confirmation record for a notification.
Fields
pc_id: Stringuser_sid: Stringacked_at: DateTime<Utc>Trait Implementations
Sourceimpl Clone for NotificationAckEntry
impl Clone for NotificationAckEntry
Sourcefn clone(&self) -> NotificationAckEntry
fn clone(&self) -> NotificationAckEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NotificationAckEntry
impl Debug for NotificationAckEntry
Sourceimpl<'de> Deserialize<'de> for NotificationAckEntry
impl<'de> Deserialize<'de> for NotificationAckEntry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for NotificationAckEntry
impl JsonSchema for NotificationAckEntry
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for NotificationAckEntry
impl RefUnwindSafe for NotificationAckEntry
impl Send for NotificationAckEntry
impl Sync for NotificationAckEntry
impl Unpin for NotificationAckEntry
impl UnsafeUnpin for NotificationAckEntry
impl UnwindSafe for NotificationAckEntry