pub struct NotificationAmendedParams {
pub amend: NotificationAmend,
}Expand description
Params of the notifications.amended push (Agent → Client) — the
flattened NotificationAmend ({ "id", "kind": "recall" }).
Fields
amend: NotificationAmendTrait Implementations
Sourceimpl Clone for NotificationAmendedParams
impl Clone for NotificationAmendedParams
Sourcefn clone(&self) -> NotificationAmendedParams
fn clone(&self) -> NotificationAmendedParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NotificationAmendedParams
impl Debug for NotificationAmendedParams
Sourceimpl<'de> Deserialize<'de> for NotificationAmendedParams
impl<'de> Deserialize<'de> for NotificationAmendedParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for NotificationAmendedParams
impl JsonSchema for NotificationAmendedParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for NotificationAmendedParams
impl RefUnwindSafe for NotificationAmendedParams
impl Send for NotificationAmendedParams
impl Sync for NotificationAmendedParams
impl Unpin for NotificationAmendedParams
impl UnsafeUnpin for NotificationAmendedParams
impl UnwindSafe for NotificationAmendedParams