pub struct NotificationNewParams {
pub notification: Notification,
}Expand description
Push payload for notifications.new. The full notification body
inline — no second round-trip needed.
Fields
notification: NotificationTrait Implementations
Sourceimpl Clone for NotificationNewParams
impl Clone for NotificationNewParams
Sourcefn clone(&self) -> NotificationNewParams
fn clone(&self) -> NotificationNewParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NotificationNewParams
impl Debug for NotificationNewParams
Sourceimpl<'de> Deserialize<'de> for NotificationNewParams
impl<'de> Deserialize<'de> for NotificationNewParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for NotificationNewParams
impl JsonSchema for NotificationNewParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for NotificationNewParams
impl RefUnwindSafe for NotificationNewParams
impl Send for NotificationNewParams
impl Sync for NotificationNewParams
impl Unpin for NotificationNewParams
impl UnsafeUnpin for NotificationNewParams
impl UnwindSafe for NotificationNewParams