pub struct NotificationTarget {
pub all: bool,
pub groups: Vec<String>,
pub pcs: Vec<String>,
}Expand description
The audience a notification was addressed to (the target: of the
publish), reconstructed from its fan-out subjects
(notifications.{all|group.X|pc.Y}). Distinct from the resolved
per-PC AudiencePc roster: this is the operator’s intent (“sent to
the it-admins group + PC minipc”), not the expanded PC list.
Fields
all: boolgroups: Vec<String>pcs: Vec<String>Trait Implementations
Sourceimpl Clone for NotificationTarget
impl Clone for NotificationTarget
Sourcefn clone(&self) -> NotificationTarget
fn clone(&self) -> NotificationTarget
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NotificationTarget
impl Debug for NotificationTarget
Sourceimpl Default for NotificationTarget
impl Default for NotificationTarget
Sourcefn default() -> NotificationTarget
fn default() -> NotificationTarget
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for NotificationTarget
impl<'de> Deserialize<'de> for NotificationTarget
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for NotificationTarget
Sourceimpl JsonSchema for NotificationTarget
impl JsonSchema for NotificationTarget
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for NotificationTarget
impl PartialEq for NotificationTarget
Sourcefn eq(&self, other: &NotificationTarget) -> bool
fn eq(&self, other: &NotificationTarget) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for NotificationTarget
impl Serialize for NotificationTarget
impl StructuralPartialEq for NotificationTarget