pub struct NotificationsSubscribeParams {}Trait Implementations
Sourceimpl Clone for NotificationsSubscribeParams
impl Clone for NotificationsSubscribeParams
Sourcefn clone(&self) -> NotificationsSubscribeParams
fn clone(&self) -> NotificationsSubscribeParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NotificationsSubscribeParams
impl Debug for NotificationsSubscribeParams
Sourceimpl Default for NotificationsSubscribeParams
impl Default for NotificationsSubscribeParams
Sourcefn default() -> NotificationsSubscribeParams
fn default() -> NotificationsSubscribeParams
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for NotificationsSubscribeParams
impl<'de> Deserialize<'de> for NotificationsSubscribeParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for NotificationsSubscribeParams
impl JsonSchema for NotificationsSubscribeParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for NotificationsSubscribeParams
impl RefUnwindSafe for NotificationsSubscribeParams
impl Send for NotificationsSubscribeParams
impl Sync for NotificationsSubscribeParams
impl Unpin for NotificationsSubscribeParams
impl UnsafeUnpin for NotificationsSubscribeParams
impl UnwindSafe for NotificationsSubscribeParams