pub struct NotificationsSubscribeResult {
pub subscription: String,
}Fields
subscription: StringTrait Implementations
Sourceimpl Clone for NotificationsSubscribeResult
impl Clone for NotificationsSubscribeResult
Sourcefn clone(&self) -> NotificationsSubscribeResult
fn clone(&self) -> NotificationsSubscribeResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NotificationsSubscribeResult
impl Debug for NotificationsSubscribeResult
Sourceimpl<'de> Deserialize<'de> for NotificationsSubscribeResult
impl<'de> Deserialize<'de> for NotificationsSubscribeResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for NotificationsSubscribeResult
impl JsonSchema for NotificationsSubscribeResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for NotificationsSubscribeResult
impl RefUnwindSafe for NotificationsSubscribeResult
impl Send for NotificationsSubscribeResult
impl Sync for NotificationsSubscribeResult
impl Unpin for NotificationsSubscribeResult
impl UnsafeUnpin for NotificationsSubscribeResult
impl UnwindSafe for NotificationsSubscribeResult