pub struct StateUnsubscribeParams {
pub subscription: String,
}Expand description
state.unsubscribe params.
Fields
subscription: StringTrait Implementations
Sourceimpl Clone for StateUnsubscribeParams
impl Clone for StateUnsubscribeParams
Sourcefn clone(&self) -> StateUnsubscribeParams
fn clone(&self) -> StateUnsubscribeParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StateUnsubscribeParams
impl Debug for StateUnsubscribeParams
Sourceimpl<'de> Deserialize<'de> for StateUnsubscribeParams
impl<'de> Deserialize<'de> for StateUnsubscribeParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StateUnsubscribeParams
impl JsonSchema for StateUnsubscribeParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for StateUnsubscribeParams
impl RefUnwindSafe for StateUnsubscribeParams
impl Send for StateUnsubscribeParams
impl Sync for StateUnsubscribeParams
impl Unpin for StateUnsubscribeParams
impl UnsafeUnpin for StateUnsubscribeParams
impl UnwindSafe for StateUnsubscribeParams