pub struct SupportLockResult {
pub released: usize,
}Expand description
support.lock response — how many grants were dropped (0 when the
caller held none; locking is idempotent, never an error).
Fields
released: usizeTrait Implementations
Sourceimpl Clone for SupportLockResult
impl Clone for SupportLockResult
Sourcefn clone(&self) -> SupportLockResult
fn clone(&self) -> SupportLockResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SupportLockResult
impl Debug for SupportLockResult
Sourceimpl<'de> Deserialize<'de> for SupportLockResult
impl<'de> Deserialize<'de> for SupportLockResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SupportLockResult
impl JsonSchema for SupportLockResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SupportLockResult
impl RefUnwindSafe for SupportLockResult
impl Send for SupportLockResult
impl Sync for SupportLockResult
impl Unpin for SupportLockResult
impl UnsafeUnpin for SupportLockResult
impl UnwindSafe for SupportLockResult