pub fn encode_secret(key: &SigningKey) -> StringExpand description
Base64 of the 32-byte seed. This is the secret; it is written to the registry and never printed by any code path that logs.
pub fn encode_secret(key: &SigningKey) -> StringBase64 of the 32-byte seed. This is the secret; it is written to the registry and never printed by any code path that logs.