pub struct CommandEnvelope {
pub kind: String,
pub target_pc_id: String,
pub expires_at: DateTime<Utc>,
pub command: Command,
}Expand description
The network form of a v2 command.
Fields
kind: Stringtarget_pc_id: StringThe exact registered pc_id of the one host allowed to run this; case is preserved and compared byte for byte.
expires_at: DateTime<Utc>Absolute UTC deadline for starting the command. Not an instruction to kill a process that is already running.
command: CommandTrait Implementations
Sourceimpl Clone for CommandEnvelope
impl Clone for CommandEnvelope
Sourceimpl Debug for CommandEnvelope
impl Debug for CommandEnvelope
Sourceimpl<'de> Deserialize<'de> for CommandEnvelope
impl<'de> Deserialize<'de> for CommandEnvelope
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more