pub fn from_json_slice<T: DeserializeOwned>(bytes: &[u8]) -> Result<T, String>Expand description
Parse JSON bytes, rejecting any key the target type doesn’t know.
pub fn from_json_slice<T: DeserializeOwned>(bytes: &[u8]) -> Result<T, String>Parse JSON bytes, rejecting any key the target type doesn’t know.